NoHubnessReduction — scikit-hubness 0.21a1 documentation

# NoHubnessReduction

class `skhubness.reduction.` `NoHubnessReduction`

  Bases: `object`

  Dummy class to test the library

  Methods Summary

  `fit`(self[, neigh_dist, neigh_ind]) |
  `fit_transform`(self[, neigh_dist, neigh_ind, …]) |
  `transform`(self[, neigh_dist, neigh_ind, …]) |

  Methods Documentation

  `fit`(self, neigh_dist=None, neigh_ind=None)
  `fit_transform`(self, neigh_dist=None, neigh_ind=None, return_distance=True, *args, **kwargs)
  `transform`(self, neigh_dist=None, neigh_ind=None, return_distance=True, *args, **kwargs)